@@ -861,6 +861,10 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       next->magick_columns=next->columns;
     if (next->magick_rows == 0)
       next->magick_rows=next->rows;
+    if ((magick_info != (const MagickInfo *) NULL) &&
+        (magick_info->mime_type != (const char *) NULL))
+      (void) SetImageProperty(next,"mime:type",magick_info->mime_type,
+        exception);
     (void) GetImageProperty(next,"exif:*",exception);
     (void) GetImageProperty(next,"icc:*",exception);
     (void) GetImageProperty(next,"iptc:*",exception);
@@ -1170,7 +1174,7 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
         Extract media type.
       */
       if (LocaleNCompare(++p,"x-",2) == 0)
-        p+=2;
+        p+=(ptrdiff_t) 2;
       (void) CopyMagickString(read_info->filename,"data.",MagickPathExtent);
       q=read_info->filename+5;
       for (i=0; (*p != ';') && (*p != '\0') && (i < (MagickPathExtent-6)); i++)
