@@ -377,12 +377,13 @@ static double ApplyEvaluateOperator(RandomInfo *random_info,const Quantum pixel,
     }
     case PowEvaluateOperator:
     {
-      if (((double) pixel < 0) && ((value-floor(value)) > MagickEpsilon))
+      if (fabs(value) <= MagickEpsilon)
+        break;
+      if (((double) pixel < 0.0) && ((value-floor(value)) > MagickEpsilon))
         result=(double) -((double) QuantumRange*pow(-(QuantumScale*(double)
-          pixel),(double) value));
+          pixel),value));
       else
-        result=(double) QuantumRange*pow(QuantumScale*(double) pixel,
-          (double) value);
+        result=(double) QuantumRange*pow(QuantumScale*(double) pixel,value);
       break;
     }
     case RightShiftEvaluateOperator:
@@ -637,7 +638,7 @@ MagickExport Image *EvaluateImages(const Image *images,
                 random_info[id],GetPixelChannel(next,channel,p[j]),op,
                 evaluate_pixel[j].channel[i]);
             }
-            p[j]+=GetPixelChannels(next);
+            p[j]+=(ptrdiff_t) GetPixelChannels(next);
             next=GetNextImageInList(next);
           }
           qsort((void *) evaluate_pixel,number_images,sizeof(*evaluate_pixel),
@@ -651,7 +652,7 @@ MagickExport Image *EvaluateImages(const Image *images,
               continue;
             q[i]=ClampToQuantum(evaluate_pixel[number_images/2].channel[i]);
           }
-          q+=GetPixelChannels(image);
+          q+=(ptrdiff_t) GetPixelChannels(image);
         }
         p=(const Quantum **) RelinquishMagickMemory((void *) p);
         if (SyncCacheViewAuthenticPixels(evaluate_view,exception) == MagickFalse)
@@ -751,7 +752,7 @@ MagickExport Image *EvaluateImages(const Image *images,
                 random_info[id],GetPixelChannel(next,channel,p[j]),j == 0 ?
                 AddEvaluateOperator : op,evaluate_pixel[x].channel[i]);
             }
-            p[j]+=GetPixelChannels(next);
+            p[j]+=(ptrdiff_t) GetPixelChannels(next);
           }
           next=GetNextImageInList(next);
         }
@@ -796,7 +797,7 @@ MagickExport Image *EvaluateImages(const Image *images,
               continue;
             q[i]=ClampToQuantum(evaluate_pixel[x].channel[i]);
           }
-          q+=GetPixelChannels(image);
+          q+=(ptrdiff_t) GetPixelChannels(image);
         }
         p=(const Quantum **) RelinquishMagickMemory((void *) p);
         if (SyncCacheViewAuthenticPixels(evaluate_view,exception) == MagickFalse)
@@ -918,7 +919,7 @@ MagickExport MagickBooleanType EvaluateImage(Image *image,
           result/=2.0;
         q[i]=clamp != MagickFalse ? ClampPixel(result) : ClampToQuantum(result);
       }
-      q+=GetPixelChannels(image);
+      q+=(ptrdiff_t) GetPixelChannels(image);
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
       status=MagickFalse;
@@ -1143,7 +1144,7 @@ MagickExport MagickBooleanType FunctionImage(Image *image,
         q[i]=ApplyFunction(q[i],function,number_parameters,parameters,
           exception);
       }
-      q+=GetPixelChannels(image);
+      q+=(ptrdiff_t) GetPixelChannels(image);
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
       status=MagickFalse;
@@ -1536,7 +1537,7 @@ MagickExport ChannelMoments *GetImageMoments(const Image *image,
         M01[channel]+=y*QuantumScale*(double) p[i];
         M01[MaxPixelChannels]+=y*QuantumScale*(double) p[i];
       }
-      p+=GetPixelChannels(image);
+      p+=(ptrdiff_t) GetPixelChannels(image);
     }
   }
   for (c=0; c <= MaxPixelChannels; c++)
@@ -1609,7 +1610,7 @@ MagickExport ChannelMoments *GetImageMoments(const Image *image,
         M03[MaxPixelChannels]+=(y-centroid[channel].y)*(y-centroid[channel].y)*
           (y-centroid[channel].y)*QuantumScale*(double) p[i];
       }
-      p+=GetPixelChannels(image);
+      p+=(ptrdiff_t) GetPixelChannels(image);
     }
   }
   channels=(double) GetImageChannels(image);
@@ -1766,7 +1767,7 @@ MagickExport ChannelPerceptualHash *GetImagePerceptualHash(const Image *image,
   if (perceptual_hash == (ChannelPerceptualHash *) NULL)
     return((ChannelPerceptualHash *) NULL);
   artifact=GetImageArtifact(image,"phash:colorspaces");
-  if (artifact != NULL)
+  if (artifact != (const char *) NULL)
     colorspaces=AcquireString(artifact);
   else
     colorspaces=AcquireString("xyY,HSB");
@@ -1854,7 +1855,6 @@ MagickExport MagickBooleanType GetImageRange(const Image *image,double *minima,
     *image_view;
 
   MagickBooleanType
-    initialize,
     status;
 
   ssize_t
@@ -1865,22 +1865,18 @@ MagickExport MagickBooleanType GetImageRange(const Image *image,double *minima,
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=MagickTrue;
-  initialize=MagickTrue;
-  *maxima=0.0;
-  *minima=0.0;
+  *maxima=MagickMinimumValue;
+  *minima=MagickMaximumValue;
   image_view=AcquireVirtualCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static) shared(status,initialize) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,image->rows,1)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
     double
-      row_maxima = 0.0,
-      row_minima = 0.0;
-
-    MagickBooleanType
-      row_initialize;
+      row_maxima = MagickMinimumValue,
+      row_minima = MagickMaximumValue;
 
     const Quantum
       *magick_restrict p;
@@ -1896,7 +1892,8 @@ MagickExport MagickBooleanType GetImageRange(const Image *image,double *minima,
         status=MagickFalse;
         continue;
       }
-    row_initialize=MagickTrue;
+    row_maxima=(double) p[0];
+    row_minima=(double) p[0];
     for (x=0; x < (ssize_t) image->columns; x++)
     {
       ssize_t
@@ -1910,39 +1907,21 @@ MagickExport MagickBooleanType GetImageRange(const Image *image,double *minima,
           continue;
         if ((traits & UpdatePixelTrait) == 0)
           continue;
-				if (row_initialize != MagickFalse)
-          {
-            row_minima=(double) p[i];
-            row_maxima=(double) p[i];
-            row_initialize=MagickFalse;
-          }
-        else
-          {
-            if ((double) p[i] < row_minima)
-              row_minima=(double) p[i];
-            if ((double) p[i] > row_maxima)
-              row_maxima=(double) p[i];
-         }
+        if ((double) p[i] < row_minima)
+          row_minima=(double) p[i];
+        if ((double) p[i] > row_maxima)
+          row_maxima=(double) p[i];
       }
-      p+=GetPixelChannels(image);
+      p+=(ptrdiff_t) GetPixelChannels(image);
     }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-#pragma omp critical (MagickCore_GetImageRange)
+    #pragma omp critical (MagickCore_GetImageRange)
 #endif
     {
-      if (initialize != MagickFalse)
-        {
-          *minima=row_minima;
-          *maxima=row_maxima;
-          initialize=MagickFalse;
-        }
-      else
-        {
-          if (row_minima < *minima)
-            *minima=row_minima;
-          if (row_maxima > *maxima)
-            *maxima=row_maxima;
-        }
+      if (row_minima < *minima)
+        *minima=row_minima;
+      if (row_maxima > *maxima)
+        *maxima=row_maxima;
     }
   }
   image_view=DestroyCacheView(image_view);
@@ -2106,7 +2085,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
   {
     ChannelStatistics *cs = channel_statistics+i;
     cs->area=0.0;
-    cs->depth=1.0;
+    cs->depth=1;
     cs->maxima=(-MagickMaximumValue);
     cs->minima=MagickMaximumValue;
     cs->sum=0.0;
@@ -2138,7 +2117,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
     {
       if (GetPixelReadMask(image,p) <= (QuantumRange/2))
         {
-          p+=GetPixelChannels(image);
+          p+=(ptrdiff_t) GetPixelChannels(image);
           continue;
         }
       for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
@@ -2207,7 +2186,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
           cs->M1+=delta_n;
         }
       }
-      p+=GetPixelChannels(image);
+      p+=(ptrdiff_t) GetPixelChannels(image);
     }
   }
   for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
@@ -2224,7 +2203,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
     cs->mean=0.0;
     if (cs->area > 0)
       {
-        cs->mean=cs->sumLD/(long double) cs->area;
+        cs->mean=(double) (cs->sumLD/(long double) cs->area);
         if (cs->area > 1.0)
           AdjArea=cs->area/(cs->area-1.0);
       }
@@ -2239,12 +2218,12 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
     else
       {
         if (cs->area > 1.0)
-          cs->standard_deviation=sqrtl(cs->M2/((long double) cs->area-1.0));
+          cs->standard_deviation=(double) sqrtl(cs->M2/((long double) cs->area-1.0));
         else
-          cs->standard_deviation=sqrtl(cs->M2/((long double) cs->area));
+          cs->standard_deviation=(double) sqrtl(cs->M2/((long double) cs->area));
         cs->variance=cs->standard_deviation*cs->standard_deviation;
-        cs->skewness=sqrtl(cs->area)*cs->M3/powl(cs->M2*AdjArea,1.5);
-        cs->kurtosis=cs->area*cs->M4/(cs->M2*cs->M2*AdjArea*AdjArea)-3.0;
+        cs->skewness=(double) (sqrtl(cs->area)*cs->M3/powl(cs->M2*AdjArea,1.5));
+        cs->kurtosis=(double) (cs->area*cs->M4/(cs->M2*cs->M2*AdjArea*AdjArea)-3.0);
       }
   }
 
@@ -2278,7 +2257,7 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
       double
         count;
 
-      count=area*histogram[(ssize_t) GetPixelChannels(image)*j+i];
+      count=(double) (area*histogram[(ssize_t) GetPixelChannels(image)*j+i]);
       channel_statistics[channel].entropy+=((long double) -count*
         MagickLog10(count)*PerceptibleReciprocalLD((long double)
         MagickLog10(number_bins)));
@@ -2324,11 +2303,11 @@ MagickExport ChannelStatistics *GetImageStatistics(const Image *image,
           {
             if (GetPixelReadMask(image,p) <= (QuantumRange/2))
               {
-                p+=GetPixelChannels(image);
+                p+=(ptrdiff_t) GetPixelChannels(image);
                 continue;
               }
             median[n++]=p[i];
-            p+=GetPixelChannels(image);
+            p+=(ptrdiff_t) GetPixelChannels(image);
           }
         }
         channel_statistics[channel].median=(double) median[
@@ -2564,7 +2543,7 @@ MagickExport Image *PolynomialImage(const Image *images,
           polynomial_pixel[x].channel[i]+=coefficient*
             pow(QuantumScale*(double) GetPixelChannel(image,channel,p),degree);
         }
-        p+=GetPixelChannels(next);
+        p+=(ptrdiff_t) GetPixelChannels(next);
       }
       image_view=DestroyCacheView(image_view);
       next=GetNextImageInList(next);
@@ -2582,7 +2561,7 @@ MagickExport Image *PolynomialImage(const Image *images,
         q[i]=ClampToQuantum((double) QuantumRange*
           polynomial_pixel[x].channel[i]);
       }
-      q+=GetPixelChannels(image);
+      q+=(ptrdiff_t) GetPixelChannels(image);
     }
     if (SyncCacheViewAuthenticPixels(polynomial_view,exception) == MagickFalse)
       status=MagickFalse;
@@ -3081,7 +3060,7 @@ MagickExport Image *StatisticImage(const Image *image,const StatisticType type,
                 (type == NonpeakStatistic))
               {
                 InsertPixelList(pixels[i],pixel_list[id]);
-                pixels+=GetPixelChannels(image);
+                pixels+=(ptrdiff_t) GetPixelChannels(image);
                 continue;
               }
             area++;
@@ -3091,9 +3070,9 @@ MagickExport Image *StatisticImage(const Image *image,const StatisticType type,
               maximum=(double) pixels[i];
             sum+=(double) pixels[i];
             sum_squared+=(double) pixels[i]*(double) pixels[i];
-            pixels+=GetPixelChannels(image);
+            pixels+=(ptrdiff_t) GetPixelChannels(image);
           }
-          pixels+=GetPixelChannels(image)*image->columns;
+          pixels+=(ptrdiff_t) GetPixelChannels(image)*image->columns;
         }
         switch (type)
         {
@@ -3152,8 +3131,8 @@ MagickExport Image *StatisticImage(const Image *image,const StatisticType type,
         }
         SetPixelChannel(statistic_image,channel,pixel,q);
       }
-      p+=GetPixelChannels(image);
-      q+=GetPixelChannels(statistic_image);
+      p+=(ptrdiff_t) GetPixelChannels(image);
+      q+=(ptrdiff_t) GetPixelChannels(statistic_image);
     }
     if (SyncCacheViewAuthenticPixels(statistic_view,exception) == MagickFalse)
       status=MagickFalse;
